require 'transfluent/transfluent_text_api'
require 'transfluent/transfluent_file_api'

module Transfluent
  class Api
    include ApiHelper
    include TransfluentTextApi 
    include TransfluentFileApi

    # The authentication token associated with this instance
    #
    # @return [string]
    attr_accessor :auth_token
    
    # Creates a new instance if Transfluent Api
    #
    # @param [Hash] default_settings default settings for some calls
    # @option default_settings [String] auth_token your auth token
    # @option default_settings [String] group default text group
    # @option default_settings [Transfluent::Language] language default text and file source language
    def initialize default_settings = {}
      @auth_token = default_settings[:auth_token]
      @defaults = default_settings

      if @defaults.has_key? :api_root
        @_ROOT_URL = @defaults.delete :api_root
      end
    end

    # Get the default text group
    #
    # @return [string]
    def default_group
      @defaults[:group]
    end

    # Set the default text group
    #
    # @param [string] value new default group for texts
    def default_group=(value)
      @defaults[:group] = value
    end
  
    # Get the default language
    #
    # @return [Transfluent::Language]
    def default_language
      @defaults[:language]
    end

    # Set the default language
    #
    # @param [Transfluent::Language] value new default language for texts
    def default_language=(value)
      @defaults[:language] = value
    end

    # Echoes back the parameter prepended with Hello
    #
    # @param world [string] any text
    # @return [string] "Hello " + world
    def hello world
      response = Net::HTTP.get(api_uri("/hello/" + world))
  
      parse_response response
    end
  
    # Authenticate against the backend
    #
    # @param [string] email Email address
    # @param [string] password Your password
    #
    # @return [string] authentication token
    def authenticate email, password
      uri = api_uri('authenticate')
      uri.query = URI.encode_www_form({'email' => email, 'password' => password})
      response = parse_response(Net::HTTP.get(uri))
  
      @auth_token = response[:token].to_s 
    end
  end
end
