require 'net/http'
require 'json'

module Transfluent
  module ApiHelper
    def api_uri method
      method = '/' + method unless method[0] == '/'
      url = @_ROOT_URL || 'https://transfluent.com/v2' 
      URI(url + method)
    end

    def execute_get uri, query = nil
      unless query.nil?
        uri.query = URI.encode_www_form query
      end

      parse_response(Net::HTTP.get(uri))
    end

    def execute_post uri, data
      parse_response(Net::HTTP.post_form(uri, data).body)
    end

    def parse_response response
      if response.is_a? String then
        json = JSON.parse(response)
      else
        json = response
      end
  
      if json["status"] == "OK" 
        response = json['response']

        if response.is_a? Hash
          symbolize_hash response
        elsif response.is_a? Array
          symbolize_array response
        else
          response
        end
      elsif json["status"] == "ERROR"
        raise Transfluent::ApiError.new json['error']['type'], json['error']['message']
      end
    end

    # Convert string keys in a hash to symbols recursively
    def symbolize_hash hash
      hash.inject({}) do |memo,(k,v)| 
        memo[(k.to_sym rescue k) || k] = if v.is_a? Hash then symbolize_hash v else v end
        memo
      end 
    end

    def symbolize_array array
      array.inject([]) do |memo, v|
        memo.push(if v.is_a? Hash then symbolize_hash v else v end)
        memo
      end
    end
  end
end
