
module Transfluent
  
  # Represents a language that can be identified by an IETF language tag
  # or Transfluent specific id
  class Language

    attr_reader :id, :code, :name

    # Get an instance of language by code
    #
    # @param [string] code code for language, 'en-us', 'en-gb' etc.
    # 
    # @return [Language]
    def self.get code
      Language.fetch if $languages_by_code.nil?

      $languages_by_code[code]
    end

    def self.get_by_id id
      Language.fetch if $languages_by_code.nil?

      $languages_by_id[id]
    end

    def initialize id, code, name
      @id = id.to_i
      @code = code
      @name = name
    end

    private

    def self.fetch
      api = Object.new
      api.extend(ApiHelper)

      uri = api.api_uri('languages')

      response = api.execute_get(uri)

      $languages_by_code = {}
      $languages_by_id = {}
      response.each do |item|
        item.each do |id, lang|
          $languages_by_code[lang[:code]] = Language.new lang[:id], lang[:code], lang[:name]
          $languages_by_id[lang[:id]] = $languages_by_code[lang[:code]]
        end
      end
    end
  end
  
end
